pub enum AffineError {
NonInvertibleTransform,
NonFiniteTransform,
UndefinedRotation,
InvalidWorldFile,
}Expand description
Errors produced by affine operations.
Variants
NonInvertibleTransform
The transform has a zero determinant and therefore has no inverse.
NonFiniteTransform
An operation requiring finite values received a non-finite matrix.
UndefinedRotation
A rotation angle is undefined for an improper or degenerate transform.
InvalidWorldFile
World File text did not contain exactly six valid floating-point values.